@@ -26,6 +26,8 @@
 #define SHOW_MAP_SHORTCUT       QKeySequence(Qt::CTRL | Qt::Key_M)
 #define NEXT_MAP_SHORTCUT       QKeySequence(QKeySequence::Forward)
 #define PREV_MAP_SHORTCUT       QKeySequence(QKeySequence::Back)
+#define NEXT_TAB_SHORTCUT       QKeySequence(QKeySequence::NextChild)
+#define PREV_TAB_SHORTCUT       QKeySequence(QKeySequence::PreviousChild)
 #define SHOW_GRAPHS_SHORTCUT    QKeySequence(Qt::CTRL | Qt::Key_G)
 #define STATISTICS_SHORTCUT     QKeySequence(Qt::CTRL | Qt::Key_S)
 #define DOWNLOAD_DEM_SHORTCUT   QKeySequence(Qt::CTRL | Qt::Key_D)
