@@ -2,7 +2,8 @@
 #define IMG_DEMTREE_H
 
 #include "common/rtree.h"
-#include "mapdata.h"
+#include "map/matrix.h"
+#include "mapdata_img.h"
 
 namespace IMG {
 
@@ -11,6 +12,7 @@ public:
 	DEMTree(const QList<MapData::Elevation> &tiles);
 
 	double elevation(const Coordinates &c) const;
+	MatrixD elevation(const MatrixC &m) const;
 
 private:
 	typedef RTree<const MapData::Elevation*, double, 2> Tree;
