@@ -4,12 +4,12 @@
 #include <QMap>
 #include <QMutex>
 #include "common/range.h"
+#include "ENC/iso8211.h"
+#include "ENC/atlasdata.h"
+#include "ENC/style_enc.h"
 #include "map.h"
 #include "projection.h"
 #include "transform.h"
-#include "ENC/iso8211.h"
-#include "ENC/atlasdata.h"
-#include "ENC/style.h"
 
 class ENCJob;
 class QDir;
@@ -41,7 +41,7 @@ public:
 	void draw(QPainter *painter, const QRectF &rect, Flags flags);
 
 	void load(const Projection &in, const Projection &out, qreal deviceRatio,
-	  bool hidpi, int layer);
+	  bool hidpi, bool hillShading, int style, int layer);
 	void unload();
 
 	bool isValid() const {return _valid;}
