@@ -2,8 +2,8 @@
 #include <QPixmapCache>
 #include "common/range.h"
 #include "common/wgs84.h"
-#include "ENC/mapdata.h"
-#include "ENC/style.h"
+#include "ENC/mapdata_enc.h"
+#include "ENC/style_enc.h"
 #include "rectd.h"
 #include "pcs.h"
 #include "encjob.h"
@@ -183,10 +183,11 @@ ENCMap::~ENCMap()
 }
 
 void ENCMap::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi, int style, int layer)
+  qreal deviceRatio, bool hidpi, bool hillShading, int style, int layer)
 {
 	Q_UNUSED(in);
 	Q_UNUSED(hidpi);
+	Q_UNUSED(hillShading);
 	Q_UNUSED(style);
 	Q_UNUSED(layer);
 
