@@ -26,10 +26,20 @@ private:
 		QuadTiles
 	};
 
+	struct Tile {
+		Tile() : size(256), ratio(1.0), mvt(false) {}
+
+		int size;
+		qreal ratio;
+		bool mvt;
+		QStringList vectorLayers;
+	};
+
 	struct Config {
 		Type type;
 		QString name;
-		QString url;
+		QStringList urls;
+		QList<Tile> tiles;
 		Range zooms;
 		RectC bounds;
 		QString layer;
@@ -41,10 +51,6 @@ private:
 		bool rest;
 		QList<KV<QString, QString> > dimensions;
 		QList<HTTPHeader> headers;
-		qreal tileRatio;
-		int tileSize;
-		bool mvt;
-		QStringList layers;
 
 		Config();
 	};
@@ -52,7 +58,7 @@ private:
 	static RectC bounds(QXmlStreamReader &reader);
 	static Range zooms(QXmlStreamReader &reader);
 	static void map(QXmlStreamReader &reader, Config &config);
-	static void tile(QXmlStreamReader &reader, Config &config);
+	static void tile(QXmlStreamReader &reader, Config &config, int layer);
 };
 
 #endif // MAPSOURCE_H
